@@ -766,7 +766,11 @@ static void cc_tatepower_even_k(element_ptr out, element_ptr in, pairing_t pairi
 	element_ptr e0im = fi_im(e0);
 	element_t *inre = fi_re(in)->data;
 	element_t *inim = fi_im(in)->data;
-	void subexpr(element_ptr e) {
+	//if beta is quadratic nonresidue in F_q^d, note that
+	//beta^q = -beta
+	//hence for x^q, x^{q^3} we have to negate the beta part of e0
+	//as the following routine does not do this
+	void qpower(element_ptr e) {
 	    element_set0(e0);
 	    element_set(((element_t *) e0re->data)[0], inre[0]);
 	    element_set(((element_t *) e0im->data)[0], inim[0]);
@@ -780,12 +784,12 @@ static void cc_tatepower_even_k(element_ptr out, element_ptr in, pairing_t pairi
 	    polymod_const_mul(e2, inim[2], e1);
 	    element_add(e0im, e0im, e2);
 	}
-	subexpr(p->xpowq[4]);
+	qpower(p->xpowq[4]);
 	element_set(e3, e0);
-	subexpr(p->xpowq[3]);
+	qpower(p->xpowq[3]);
 	element_neg(e0im, e0im);
 	element_mul(e3, e3, e0);
-	subexpr(p->xpowq[1]);
+	qpower(p->xpowq[1]);
 	element_neg(e0im, e0im);
 	element_mul(e0, e0, in);
 	element_invert(e0, e0);
@@ -905,7 +909,7 @@ static void pairing_init_c_param_even_k(pairing_t pairing, c_param_t param)
     for (i=0; i<d; i++) {
 	element_set_mpz(poly_coeff(irred, i), param->coeff[i]);
     }
-    element_set1(poly_coeff(irred, i));
+    element_set1(poly_coeff(irred, d));
 
     field_init_polymod(p->Fqd, irred);
     element_clear(irred);
