@@ -127,7 +127,7 @@ static void generic_pow(element_ptr x, element_ptr a, mpz_ptr n)
     clear_pow_window(k, a_lookup);
 }
 
-static void naive_generic_pow(element_ptr x, element_ptr a, mpz_ptr n)
+void naive_generic_pow(element_ptr x, element_ptr a, mpz_ptr n)
 {
     int s;
 
