@@ -147,8 +147,8 @@ static void compute_j(mpc_t j, mpc_t tau)
     mpc_init(h);
     mpc_init(z0);
     compute_h(h, tau);
-    //TODO: use mul 2exp functions
-    mpc_mul_ui(z0, h, 256);
+    //mpc_mul_ui(z0, h, 256);
+    mpc_mul_2exp(z0, h, 8);
     mpc_add_ui(z0, z0, 1);
     mpc_pow_ui(z0, z0, 3);
     mpc_div(j, z0, h);
