@@ -248,6 +248,13 @@ void poly_random_monic(element_ptr f, int deg)
     element_set1(poly_coeff(f, i));
 }
 
+element_ptr polymod_coeff(element_ptr e, int i)
+{
+    element_t *coeff = e->data;
+
+    return coeff[i];
+}
+
 static void polymod_random(element_ptr e)
 {
     polymod_field_data_ptr p = e->field->data;
